﻿using System.Windows;
using System.Windows.Media;
using System.Windows.Controls;
using System.Windows.Input;
using System.Collections.ObjectModel;
using C1.WPF;
using C1.WPF.DataGrid;

namespace TableDragDrop
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        C1DragDropManager ddm;
        public MainWindow()
        {
            InitializeComponent();

            c1DataGrid1.ItemsSource = Person.Generate(10);
            c1DataGrid2.ItemsSource = Person.Generate(10);

            ddm = new C1DragDropManager();

            c1DataGrid1.LoadedRowPresenter += (s, e) =>
            {
                ddm.RegisterDropTarget(e.Row.Presenter, true);
                ddm.RegisterDragSource(e.Row.Presenter, DragDropEffect.Copy, ModifierKeys.None);
            };

            c1DataGrid2.LoadedRowPresenter += (s, e) =>
            {
                ddm.RegisterDropTarget(e.Row.Presenter, true);
                ddm.RegisterDragSource(e.Row.Presenter, DragDropEffect.Copy, ModifierKeys.None);
            };

            ddm.DragDrop += new DragDropEventHandler(DragDrop);

            ddm.DragStart += new DragDropEventHandler(DragStart);
        }

        void DragStart(object source, DragDropEventArgs e)
        {
            C1.WPF.DataGrid.DataGridRow row = ((DataGridRowPresenter)e.DragSource).Row;
            string mark = row.DataItem.ToString();

            Border border = ddm.TargetMarker as Border;
            border.Height = 32d;
            border.Child = new ContentControl()
            {
                Foreground = new SolidColorBrush(Colors.Black),
                FontSize = 16d,
                FontWeight = FontWeights.DemiBold,
                Content = mark
            };
        }

        void DragDrop(object source, DragDropEventArgs e)
        {
            var source_row = ((DataGridRowPresenter)e.DragSource).Row;
            var source_table = source_row.DataGrid;


            var target_row = ((DataGridRowPresenter)e.DropTarget).Row;
            var target_table = target_row.DataGrid;

            if (source_table != target_table)
            {
                ((ObservableCollection<Person>)source_table.ItemsSource).Remove((Person)source_row.DataItem);
                ((ObservableCollection<Person>)target_table.ItemsSource).Add((Person)source_row.DataItem);
            }
            else
                System.Media.SystemSounds.Beep.Play();
        }
    }
}
